#!BPY

"""
Name: '_Ipo Reverter_249'
Blender: 237
Group: 'Animation'
Tip: 'Ipo Reverter (Ipo Converter in reverse)'
"""

#==========================================================#
# Ipo Reverter (from dLoc, dRot, dScale to Loc, Rot, Scale)
#
# This script is based on Ipo Converter by Dalai Felinto.
# It was created to reverse the actions of Ipo Converter.
#
# Move the current frame to 1, just in case.
#
# D'Lanor
# December 17, 2009
#==========================================================#

# -------------------------------------------------------------------------- 
# ***** BEGIN GPL LICENSE BLOCK ***** 
# 
# This program is free software; you can redistribute it and/or 
# modify it under the terms of the GNU General Public License 
# as published by the Free Software Foundation; either version 2 
# of the License, or (at your option) any later version. 
# 
# This program is distributed in the hope that it will be useful, 
# but WITHOUT ANY WARRANTY; without even the implied warranty of 
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
# GNU General Public License for more details. 
# 
# You should have received a copy of the GNU General Public License 
# along with this program; if not, write to the Free Software Foundation, 
# Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. 
# 
# ***** END GPL LICENCE BLOCK ***** 
# -------------------------------------------------------------------------- 

import Blender
import math

def createCurve(m_ipo, m_curve, offset):
    name = m_curve.name[1:]
    m_ipo.addCurve(name)

    for i in m_ipo.curves:
        if (i.name == name):
            new_curve = i

    points = m_curve.getPoints()

    for p in points:
        pt = p.pt
        new_curve.append((pt[0],(pt[1] + offset)))

    new_curve.interpolation = m_curve.interpolation
    new_curve.setExtrapolation(m_curve.getExtrapolation())


curframe = Blender.Get('curframe')
obj = Blender.Object.GetSelected()

for ob in obj:
    ipo = ob.getIpo()

    dLocX = ipo[Blender.Ipo.OB_DLOCX]
    dLocY = ipo[Blender.Ipo.OB_DLOCY]
    dLocZ = ipo[Blender.Ipo.OB_DLOCZ]

    dRotX = ipo[Blender.Ipo.OB_DROTX]
    dRotY = ipo[Blender.Ipo.OB_DROTY]
    dRotZ = ipo[Blender.Ipo.OB_DROTZ]

    dScaleX = ipo[Blender.Ipo.OB_DSCALEX]
    dScaleY = ipo[Blender.Ipo.OB_DSCALEY]
    dScaleZ = ipo[Blender.Ipo.OB_DSCALEZ]

    iponame = (ipo.name + '_rev')
    n_ipo = Blender.Ipo.New('Object', iponame)

    obLoc = ob.getLocation()
    obRot = ob.getEuler()
    obSize = ob.getSize()

    #obRot[0] = obRot[0]/( 2 * 3.1416)*360
    #obRot[1] = obRot[1]/( 2 * 3.1416)*360
    #obRot[2] = obRot[2]/( 2 * 3.1416)*360

    obRot[0] = math.degrees(obRot[0])
    obRot[1] = math.degrees(obRot[1])
    obRot[2] = math.degrees(obRot[2])

    ############
    ## Location:
    if dLocX:
        LocX = (obLoc[0] + (dLocX[curframe] - dLocX[1]))
        createCurve(n_ipo, dLocX, LocX)

    if dLocY:
        LocY = (obLoc[1] + (dLocY[curframe] - dLocY[1]))
        createCurve(n_ipo, dLocY, LocY)

    if dLocZ:
        LocZ = (obLoc[2] + (dLocZ[curframe] - dLocZ[1]))
        createCurve(n_ipo, dLocZ, LocZ)

    ############
    ## Rotation:
    if dRotX:
        RotX = (obRot[0] + (dRotX[curframe] - dRotX[1]))
        RotX = (RotX / 10)
        createCurve(n_ipo, dRotX, RotX)

    if dRotY:
        RotY = (obRot[1] + (dRotY[curframe] - dRotY[1]))
        RotY = (RotY / 10)
        createCurve(n_ipo, dRotY, RotY)

    if dRotZ:
        RotZ = (obRot[2] + (dRotZ[curframe] - dRotZ[1]))
        RotZ = (RotZ / 10)
        createCurve(n_ipo, dRotZ, RotZ)

    ###########
    ## Scale:
    if dScaleX:
        ScaleX = (obSize[0] + (dScaleX[curframe] - dScaleX[1]))
        createCurve(n_ipo, dScaleX, ScaleX)

    if dScaleY:
        ScaleY = (obSize[1] + (dScaleY[curframe] - dScaleY[1]))
        createCurve(n_ipo, dScaleY, ScaleY)

    if dScaleZ:
        ScaleZ = (obSize[2] + (dScaleZ[curframe] - dScaleZ[1]))
        createCurve(n_ipo, dScaleZ, ScaleZ)



    ob.setIpo(n_ipo)

Blender.Window.RedrawAll()